$def with (crashtype)

RUCIO
SCIENTIFIC DATA MANAGEMENT
Rucio authentication server could not $if crashtype == "no_result": finalize your token request, no authorization content returned from the auth server. $elif crashtype == "contact": authorize your access, please check your access credentials. $elif crashtype == "bad_request": recognize and process your request. $elif crashtype == "unknown_identity": find your OIDC identity linked to any Rucio account. $else: process your request due to internal error.